### Functions for putting tables in LaTeX format. Source this into
### another shell script.

# Lots of functions use OUTFILE. Set a default just in case:
#OUTFILE=/dev/null

UseOutfile(){
    OUTFILE=$1
    touch -a "$OUTFILE"
    mv "$OUTFILE" "$OUTFILE.bak"
    touch -a "$OUTFILE"
}

MakeColumns(){
    while test $# -gt 1; do
    cat <<EOF >>"$OUTFILE"
\\multicolumn{1}{|c|}{\\textbf{$1}} &
EOF
    shift
    done
    cat <<EOF >>"$OUTFILE"
\\multicolumn{1}{|c|}{\\textbf{$1}} \\\\
EOF
}

BeginTable(){
    # Format: database "command;" "caption" label "column format" column names
    DB=$1
    shift
    COMMAND=$1
    shift
    CAPTION=$(echo "$1" | sed "s/_/\\\_/g")
    shift
    LABEL=$1
    shift
    FORMAT=$1
    shift
    REST=$*

    #echo DB=$DB
    #echo COMMAND=$COMMAND
    #echo LABEL=$LABEL
    #echo CAPTION=$CAPTION
    #echo FORMAT=$FORMAT
    #echo REST=$REST

    cat <<EOF >> "$OUTFILE"
    \\begin{longtable}{$FORMAT}
EOF
    if test "x$CAPTION" != "xnone"; then
        cat <<EOF >> "$OUTFILE"
    \\caption{$CAPTION}
EOF
    fi
    if test "x$LABEL" != "xnone"; then
        cat <<EOF >> "$OUTFILE"
    \\label{tab:$LABEL} \\\\
EOF
    fi
    cat <<EOF >> "$OUTFILE"
 \\hline
EOF

    MakeColumns $REST

    cat <<EOF >> "$OUTFILE"
    \\hline \\hline  \\endfirsthead 
EOF

    if test "x$CAPTION" != "xnone"; then
        cat <<EOF >> "$OUTFILE"
    \\caption{$CAPTION (vervolgd)} \\\\ 
EOF
    fi

    cat <<EOF >> "$OUTFILE"
\\hline
EOF

    MakeColumns $REST

    cat <<EOF >> "$OUTFILE"
    \\hline \\hline \\endhead \\endfoot
EOF
}

EndTable(){
cat <<EOF >> "$OUTFILE"
\\end{longtable}
EOF
}

Query(){
    DB=$1
    COMMAND=$2
    if test $# -eq 2; then
        OPTIONS="--skip-column-names"
    else
        OPTIONS=$3
    fi

    mysql $DB $OPTIONS -e "$COMMAND" | sed "s/\&/+/g;s/_/\\\_/g;s/\t/ \& /g;s/$/ \\\/g;s/$/\\\ \\\hline/g;s/,/, /g" >> "$OUTFILE"
}

MakeTable(){
    DB=$1
    shift
    COMMAND=$1
    shift
    CAPTION=$1
    shift
    LABEL=$1
    shift
    FORMAT=$1
    shift

    if test "x$FORMAT" != "xnone"; then
        # Start new table:
        BeginTable $DB "$COMMAND" "$CAPTION" $LABEL $FORMAT  $*
    fi
    Query $DB "$COMMAND"

    if test "x$FORMAT" != "xnone"; then
        # End table:
        EndTable
    fi
}

ShowCreateTable(){
    TABLE=$1
    if test $# -eq 1; then
        DB=nsrsafe
    else
        DB=$2
    fi

    mysql --skip-column-names "$DB" -e "show create table $TABLE;" | cut -f2 | tail -1 | sed "s/\\\n/\n/g" | ./cutoff.sh >> "$OUTFILE"

}
